@@ -1,9 +1,9 @@
 CREATE TABLE ts2_channel_privileges (
-  i_cp_id integer primary key,
-  i_cp_server_id integer ,
-  i_cp_channel_id integer ,
-  i_cp_client_id integer ,
+  i_cp_id integer PRIMARY KEY,
+  i_cp_server_id integer,
+  i_cp_channel_id integer,
+  i_cp_client_id integer,
   b_cp_flag_admin integer,
   b_cp_flag_autoop integer,
   b_cp_flag_autovoice integer
-);
+) ;
